@@ -68,6 +68,7 @@ def GET(
         uri: an uri, it can be an domain or ip, type must is cls<str>.
         post_data: <dict>, params.
         http_headers: set request's headers, default is None.
+        content_type: <class:ContentType> set request's headers content type.
         time_out: time out for access remote uri , default value is 1 seconds.
 
     - Returs:
@@ -118,6 +119,7 @@ def POST(
         uri: an uri, it can be an domain or ip, type must is cls<str>.
         data: submit request post data.
         http_headers: set request's headers, default is None.
+        content_type: <class:ContentType> set request's headers content type.
         time_out: time out for access remote uri , default value is 1 seconds.
         charset: set the http charset, default is UTF-8
 
@@ -157,18 +159,29 @@ def DELETE(uri, post_data={}, http_headers=None, content_type=ContentType.URLENC
     try:
         req = None
         if post_data:
-            m_params_data_str = serializePostData(
-                translateDict2queryStr(post_data,enCoding=charset), isBytes=False, enCoding=charset
-                )
-            if uri.find("?") > -1:
-                uri += "&" + m_params_data_str
+            if content_type== ContentType.URLENCODED:
+                m_params_data_str = serializePostData(
+                    translateDict2queryStr(post_data,enCoding=charset), isBytes=False, enCoding=charset
+                    )
+                if uri.find("?") > -1:
+                    uri += "&" + m_params_data_str
+                else:
+                    uri += "?" + m_params_data_str
             else:
-                uri += "?" + m_params_data_str
-        if http_headers:
-            http_headers = requestContentType(http_headers, content_type)
-            req = request.Request(uri, headers=http_headers, method=u"DELETE")
+                m_params_data_str= serializePostData(post_data=post_data,enCoding=charset)
+        if content_type==ContentType.URLENCODED:
+            if http_headers:
+                http_headers = requestContentType(http_headers, content_type)
+                req = request.Request(uri, headers=http_headers, method=u"DELETE")
+            else:
+                req = request.Request(uri, method=u"DELETE")
         else:
-            req = request.Request(uri, method=u"DELETE")
+            # "text/xml","multipart/form-data",未处理
+            if http_headers:
+                http_headers = requestContentType(http_headers, content_type)
+                req = request.Request(uri,data= m_params_data_str, headers=http_headers, method=u"DELETE")
+            else:
+                req = request.Request(uri,data=m_params_data_str, method=u"DELETE")
         with request.urlopen(req, timeout=time_out) as response:
             return response.getcode(), response.read()
     except HTTPError as e:
