@@ -1,7 +1,6 @@
 import json
 import copy
 import random
-from signal import raise_signal
 from typing import List, Tuple, Dict
 from urllib import parse
 from types import FunctionType
@@ -842,7 +841,6 @@ class RPC:
                 m_uri = ret["uri"]
                 m_params = ret["params"]
                 m_method = ret["method"]
-                m_method= m_method.upper()
                 m_headers = {}
                 if "headers" in kwargs:
                     if isinstance(kwargs["headers"], dict):
@@ -919,7 +917,7 @@ class RPC:
                 return {"state": -1, "msg": e.args}
             try:
                 if m_method == u"GET":
-                    logging.info("access api:(%s), method(GET)." % m_uri)
+                    logging.info("access api:(%s), method(%s)." % (m_uri, m_method))
                     state, ret = GET(uri=m_uri, http_headers=m_headers, time_out=15)
                     if state == 200:
                         try:
@@ -945,8 +943,8 @@ class RPC:
                             }
                 elif m_method == u"POST":
                     logging.info(
-                        "access api:(%s), method(POST),postdata:%s."
-                        % (m_uri, kwargs["data"])
+                        "access api:(%s), method(%s),postdata:%s."
+                        % (m_uri, m_method, kwargs["data"])
                     )
                     state, ret = POST(
                         m_uri,
@@ -980,15 +978,15 @@ class RPC:
                             }
                 elif m_method == u"PUT":
                     logging.info(
-                        "access api:(%s), method(PUT),postdata:%s."
-                        % (m_uri, params_data)
+                        "access api:(%s), method(%s),postdata:%s."
+                        % (m_uri, m_method, params_data)
                     )
 
                     # 还没有写PUT方法
                     raise Exception("urllib PUT方法还没写.")
                 elif m_method == u"DELETE":
                     # 还没有写DELETE方法
-                    logging.info("access api:(%s), method(DELETE)" % m_uri)
+                    logging.info("access api:(%s), method(%s)" % (m_uri,m_method))
                     if "data" in kwargs:
                         state, ret = DELETE(
                             m_uri,
@@ -1025,7 +1023,7 @@ class RPC:
                                 "msg": 'remote call "%s" error.(%s)' % (m_uri,e.args),
                             }
                 else:
-                    return {"state":-1, "msg":"restful method is error. POST|GET|DELET|PUT(unrealized)|OPTIONS(unrealized)|HEAD(unrealized)"}
+                    return {"state":-1, "msg":"restful method(%s) is error. POST|GET|DELETE|PUT(unrealized)|OPTIONS(unrealized)|HEAD(unrealized)"%(m_method)}
             except Exception as e:
                 return {"state": -1, "msg": e.args}
         else:
