@@ -9,7 +9,7 @@ class TestSpider(unittest.TestCase):
         spider_http = m_http()
         Extraction_set = lineblock(5, 0.2, 50)
         content, statucode = spider_http.getcontent(
-            "https://www.163.com/news/article/GVNDGPOB000189FH.html?clickfrom=w_yw"
+            "https://www.sipwps.com/x/113923.html"
         )
         # content= str(content,"utf-8")
         self.assertEqual((statucode,), (200,))
